/*This do file reads the data from “Data_ for_VAR.xls” and runs the monthly VAR regressions. 
*/

version 10

/*Change the main directory*/
cd "H:\Workspace_EAR\EPU"
clear all
set memory 100m
set matsize 800
set more off
pause on
capture log close


import excel using Data_for_VAR.xlsx,  sheet("out_data_var_m")  firstrow

tsset date_var, monthly


/*defining various variables*/
generate log_nikkei=ln(nikkei)
generate log_ip=ln(ip)
generate log_ip_inv=ln(ip_inv)
generate log_ip_cons=ln(ip_cons)
generate log_ip_consdur=ln(ip_consdur)
generate log_ip_consnondur=ln(ip_consnondur)
generate log_tertiary=ln(tertiary)
generate log_tertiary_essential=ln(tertiary_essential)
generate log_tertiary_nonessential=ln(tertiary_nonessential)

generate log_synth_cons=ln(synth_cons)
generate log_real_cons_act=ln(real_cons_act)

generate log_real_cons_act_dur=ln(real_cons_act_dur)
generate log_real_cons_act_nondur=ln(real_cons_act_nondur)

generate log_real_services=ln(real_services)


generate log_emp=ln(emp)
generate log_emp_part=ln(emp_part)
generate log_emp_full=ln(emp_full)
generate log_emp_tot_hours=ln(emp_tot_hours)

generate log_emp_smallc=ln(emp_smallc)
generate log_emp_bigc=ln(emp_bigc)
generate log_wage_index=ln(wage_index)

generate log_build_index=ln(build_index)
generate log_priv_investment=ln(priv_investment)
generate log_building_start=ln(building_start)
generate log_mach_order=ln(mach_order)
generate log_housing_const=ln(housing_const)
generate log_housing_start=ln(housing_start)
generate log_effect_exc_ratet=ln(effect_exc_rate)
generate log_cpi=ln(cpi)
					
generate log_mon_base=ln(mon_base)					
generate log_oil_price=ln(oil_price)		
generate log_public_invest=ln(public_invest)	
				
irf set, clear


/*baseline VAR with EPU, employment and industrial production, 4 lags are used based on AIC */

varsoc pol_uncert log_emp log_ip , maxlag(12) exog(date_var)

/*Baseline */

var pol_uncert log_emp log_ip, lags(1/4) exog(date_var) 

/*Calculating the residuals for EPU*/

predict res_epu, residuals equation(pol_uncert)

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)

/*Alternative specifications */

/*With stock market index */

var pol_uncert log_nikkei log_emp log_ip, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_nikkei log_emp log_ip) replace

irf graph oirf, impulse(pol_uncert) response(log_nikkei log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)

/*With stock market volatility index */


var pol_uncert nikkei_vol log_emp log_ip, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert nikkei_vol log_emp log_ip) replace

irf graph oirf, impulse(pol_uncert) response(nikkei_vol log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)

/*With Global Policy Uncertainty index */


var global_epu_excjpn pol_uncert log_emp log_ip, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(global_epu_excjpn pol_uncert log_emp log_ip) replace

irf graph oirf, impulse(global_epu_excjpn pol_uncert) response(log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)

/*With VIX index */


var vix pol_uncert log_emp log_ip, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(vix pol_uncert log_emp log_ip) replace

irf graph oirf, impulse(vix pol_uncert) response(log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)

/*Bigger VAR */


var pol_uncert log_nikkei shadow_call_rate log_mon_base log_effect_exc_rate log_cpi log_wage_index log_emp_tot_hours log_ip, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_nikkei shadow_call_rate log_mon_base log_effect_exc_rate log_cpi log_wage_index log_emp_tot_hours log_ip) replace

irf graph oirf, impulse(pol_uncert) response(log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)


/*baseline VAR with 12 lags */

var pol_uncert log_emp log_ip, lags(1/12) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)

/*baseline VAR without time trend */

var pol_uncert log_emp log_ip, lags(1/4) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)

/*baseline VAR IP first */

var log_ip log_emp pol_uncert  , lags(1/4) 

irf create myirf, set(myirf) step(60) order(log_ip log_emp pol_uncert) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)


/*baseline VAR post-1995 */


var pol_uncert log_emp log_ip if date_var>419, lags(1/4) exog(date_var)

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)


/*baseline VAR pre-2007 */


var pol_uncert log_emp log_ip if date_var<564, lags(1/4) exog(date_var)

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)


/*baseline VAR with an index of building and civil engineering work by the public sector  */


var pol_uncert log_public_invest log_emp log_ip, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_public_invest log_emp log_ip) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)


*baseline VAR with oil prices  */


var pol_uncert log_oil_price log_emp log_ip, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_oil_price log_emp log_ip) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip)

irf table oirf, irf(myirf) impulse(pol_uncert)


*baseline VAR with different components of economic activity  */

*INVESTMENT  */

*Index of Building and Civil Engineering Work by Private Sector  */

var pol_uncert log_emp log_ip log_build_index, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_build_index) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_build_index)

irf table oirf, irf(myirf) impulse(pol_uncert)

*Index of Private Non-Housing Construction Investment   */

var pol_uncert log_emp log_ip log_priv_investment, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_priv_investment) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_priv_investment)

irf table oirf, irf(myirf) impulse(pol_uncert)


 
*Index of Building starts   */

var pol_uncert log_emp log_ip log_building_start, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_building_start) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_building_start)

irf table oirf, irf(myirf) impulse(pol_uncert)


*Index of machinery orders   */

var pol_uncert log_emp log_ip log_mach_order, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_mach_order) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_mach_order)

irf table oirf, irf(myirf) impulse(pol_uncert)

*Index of housing starts  */

var pol_uncert log_emp log_ip log_housing_start, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_housing_start) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_housing_start)

irf table oirf, irf(myirf) impulse(pol_uncert)

*Index of investment goods production */

var pol_uncert log_emp log_ip log_ip_inv, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_ip_inv) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_ip_inv)

irf table oirf, irf(myirf) impulse(pol_uncert)



*CONSUMPTION */


*Industrial production consumption goods */

var pol_uncert log_emp log_ip log_ip_cons, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_ip_cons) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_ip_cons)

irf table oirf, irf(myirf) impulse(pol_uncert)


*Industrial production consumption goods durable */

var pol_uncert log_emp log_ip log_ip_consdur, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_ip_consdur) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_ip_consdur)

irf table oirf, irf(myirf) impulse(pol_uncert)



*Industrial production consumption goods nondurable */

var pol_uncert log_emp log_ip log_ip_consnondur, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_ip_consnondur) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_ip_consnondur)

irf table oirf, irf(myirf) impulse(pol_uncert)



*Index of tertiary industry activity, broad-ranging personal services */

var pol_uncert log_emp log_ip log_tertiary, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_tertiary) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_tertiary)

irf table oirf, irf(myirf) impulse(pol_uncert)


*Index of tertiary industry activity, broad-ranging essential personal services */


var pol_uncert log_emp log_ip log_tertiary_essential, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_tertiary_essential) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_tertiary_essential)

irf table oirf, irf(myirf) impulse(pol_uncert)

*Index of tertiary industry activity, broad-ranging nonessential personal services */


var pol_uncert log_emp log_ip log_tertiary_nonessential, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_tertiary_nonessential) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_tertiary_nonessential)

irf table oirf, irf(myirf) impulse(pol_uncert)


*Synthetic consumption index */


var pol_uncert log_emp log_ip log_synth_cons, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_synth_cons) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_synth_cons)

irf table oirf, irf(myirf) impulse(pol_uncert)

*Real consumption activity index (only available from 2003) */


var pol_uncert log_emp log_ip log_real_cons_act, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_real_cons_act) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_real_cons_act)

irf table oirf, irf(myirf) impulse(pol_uncert)

*Real consumption activity index durable (only available from 2003) */


var pol_uncert log_emp log_ip log_real_cons_act_dur, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_real_cons_act_dur) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_real_cons_act_dur)

irf table oirf, irf(myirf) impulse(pol_uncert)



*Real consumption activity index nondurable (only available from 2003) */


var pol_uncert log_emp log_ip log_real_cons_act_nondur, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_real_cons_act_nondur) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_real_cons_act_nondur)

irf table oirf, irf(myirf) impulse(pol_uncert)

*Real services index (only available from 2003) */


var pol_uncert log_emp log_ip log_real_services, lags(1/4) exog(date_var) 

irf create myirf, set(myirf) step(60) order(pol_uncert log_emp log_ip log_real_services) replace

irf graph oirf, impulse(pol_uncert) response(log_emp log_ip log_real_services)

irf table oirf, irf(myirf) impulse(pol_uncert)


