/*This do file reads the data from “Data_ for_VAR.xls” and runs the quarterly VAR regressions. 
*/

version 10

/*Change the main directory*/
cd "H:\Workspace_EAR\EPU"
clear all
set memory 100m
set matsize 800
set more off
pause on
capture log close


import excel using Data_for_VAR.xlsx,  sheet("out_data_var_q")  firstrow

tsset date_var, quarterly


/*defining various variables*/

generate log_gdp=ln(real_gdp)
generate log_invest_nonres=ln(real_invest_nonres)
generate log_invest_res=ln(real_invest_res)
generate log_cons=ln(real_cons)
generate log_privfixedcapform=ln(gross_privfixed_capform)
generate log_nikkei=ln(nikkei)


/*Lag length analysis based on different criteria, 2 lags are used based on AIC*/

varsoc pol_uncert log_nikkei log_gdp log_privfixedcapform, maxlag(12) exog(date_var)

/*Baseline*/


var pol_uncert log_nikkei log_gdp log_privfixedcapform, lags(1/2) exog(date_var) 

/*Calculating the residuals for EPU*/
predict res_epu, residuals equation(pol_uncert)

irf create myirf_q, set(myirf_q) step(20) order(pol_uncert log_nikkei log_gdp log_privfixedcapform) replace

irf graph oirf, impulse(pol_uncert) response(log_nikkei log_gdp log_privfixedcapform)

irf table oirf, irf(myirf_q) impulse(pol_uncert)




